// src/xt-uploader/index.js
const utils = require("./utils");
Component({
	/**
	 * 组件的属性列表
	 */
	properties: {
		title: {
			type: String,
			value: "",
		},
		fileList: {
			type: Array,
			value: [],
		},
		max: {
			type: Number,
			value: 9,
		},
		uploadDesc: {
			type: String,
			value: "",
		},
		// ["album", "camera"]
		sourceType: {
			type: Array,
			value: ["camera"],
		},
		customUpload: {
			type: Boolean,
			value: false,
		},
		disabled: {
			type: Boolean,
			value: false,
		},
	},

	/**
	 * 组件的初始数据
	 */
	data: {},

	/**
	 * 组件的方法列表
	 */
	methods: {
		// 预览
		onPreviewImage(e) {
			const url = e.target.dataset.url;
			// const index = e.target.dataset.index;
			wx.previewImage({
				urls: this.properties.fileList,
				current: url,
			});
		},
		// 删除
		onDelete(e) {
			const url = e.currentTarget.dataset.url;
			const index = e.currentTarget.dataset.index;
			this.properties.fileList.splice(index, 1);
			this.triggerEvent("delete", {
				fileList: this.properties.fileList,
				url,
				index,
			});
		},
		// 上传成功
		onUploadSuccess(url) {
			this.triggerEvent("upload", { fileList: this.properties.fileList, url });
		},
		// 点击上传
		startTakePhoto() {
			const _this = this;
			if (this.properties.customUpload) {
				this.triggerEvent("upload", {});
				return;
			}
			wx.chooseMedia({
				count: 1,
				mediaType: ["image"],
				sizeType: ["compressed"],
				sourceType: this.properties.sourceType,
				success(res) {
					console.log(res, "0000");
					// tempFilePath可以作为img标签的src属性显示图片
					const tempFilePaths = res.tempFiles[0].tempFilePath;
					_this.uploadImage_v(tempFilePaths);
				},
				fail(error) {
					wx.showToast({
						title: error && error.errMsg,
						icon: "none",
					});
				},
			});
		},
		// 上传文件
		uploadImage_v(filePaths) {
			let _this = this;
			const { fileList } = _this.properties;
			wx.showLoading("图片上传中");
			utils.newHttp(
				"/core/file/oss/miniProgramPolicy",
				"GET",
				{
					dir: "microComponents",
				},
				(res) => {
					const { host, signature, accessKeyId, policy, dir } = res.data;
					let path = filePaths;
					let name = utils.random_string(32) + utils.get_suffix(path);
					wx.uploadFile({
						url: host,
						filePath: filePaths,
						name: "file",
						formData: {
							key: dir + "/" + name,
							policy,
							success_action_status: "200",
							OSSAccessKeyId: accessKeyId,
							signature,
						},
						header: {
							"Content-Type": "multipart/form-data",
							"wow-token": "c9fbecb5fdeecb78e8745db9225d88e1",
						},
						success: (res) => {
							if (res.statusCode == 200) {
								let url = host + dir + "/" + name;
								fileList.push(url);
								_this.onUploadSuccess(url);
								wx.showToast({
									icon: "success",
									title: "上传成功",
								});
							}
						},
						fail: (err) => {
							wx.showToast({
								icon: "error",
								title: err.errMsg || "网络错误，请重试",
							});
						},
					});
				}
			);
		},
	},
});
